function parDistCmp(initXfree, finalXfree, ...
    isLog10, isNormalize, isAddOrig, ylimRange)
% PARDISTCMP visualize the original and final parameter distribusions
%
% parDistCmp(initXfree, finalXfree) creates the figure showing the
% distribution of each optimized parameter value.
%
% parDistCmp(initXfree, finalXfree, isLog) creates the figure showing the
% distribution of each optimized parameter value in log10 scale.
%
% parDistCmp(initXfree, finalXfree, isLog, isNormalize) normalize the
% optimized parameter values with the range of InitX, if isNormalize ==
% 1 (default: isNormalize = 0). If normalized values are equal to 1/-1,
% they correspond to the maximum/minimum value of initial parameter
% distributions.
%
% parDistCmp(initXfree, finalXfree, isLog, isNormalize, isAddOrig) add subplot
% showing the distribution of initial parameter values, if isAddOrig == 1|2,
% or overlay if isAddOrig == 3, (default: 0).
%
% parDistCmp(initXfree, finalXfree, isLog, isNormalize, isAddOrig, ylimRange)
% define the figure ylim range manually.
%
%
% Example:
%   parDistCmp(X(:,:,1),X(:,:,end),1,1,0)
%
% My specific case example:
%   finalX = FinalXsorted(:,FinalXsorted(1,:,1)~=FinalXsorted(2,:,1))';
%   parDistCmp(exp(X(:,:,1)),finalX,1,1,0)
%
% My specific case example2:
%   for k = 1:3000
%     ss(k) = (Y(:,k,end) - ystar)'*(Y(:,k,end) - ystar);
%   end
%   [a b] = sort(ss);
%   Xsort = X(:,b,20);
%   parDistCmp(Xsort([1:31],:),Xsort([32 34:63],:),0,1,0)
%
% My specific case example 3:
%   parDistCmp(finalXwoM1, finalX([1:11 20:25],:), 1,1,0)
%   parDistCmp(finalXO, finalXB([1:15 21:end-1],:), 1,1,0)
%   parDistCmp(finalXO, finalXB([1:end-1],:), 1,1,0)

if nargin == 2,isLog10    = 0; end
if nargin <= 3,isNormalize= 0; end
if nargin <= 4,isAddOrig  = 0; end
if nargin <= 5,autoYlim   = 1; else autoYlim = 0;end


if isLog10
    initXfree  = log10(initXfree)';
    finalXfree = log10(finalXfree)';
    isLog10Str = 'log10';
else
    initXfree  = initXfree';
    finalXfree = finalXfree';
    isLog10Str = '';
end

initSampNum = size(finalXfree,1); %#ok<NASGU>
finalSampNum = size(finalXfree,1); %#ok<NASGU>
freeNum = size(initXfree,2);
if freeNum ~= size(finalXfree,2)
    error('Numbers of free parameters do not match')
end

%% Settings
axLabelFontSize= 16;
axFontSize     = 20;
titleFontSize  = 20;
yellowNumInit  = 10;
yellowNumFinal = 10;

%% Normalize values

if isNormalize == 1;
    initXfreeMean  = (max(initXfree) + min(initXfree))/2;
    initXfreeRange =  max(initXfree) - min(initXfree);
    initXfreeRange = diag(1./initXfreeRange);
    initXfree = ...
        (initXfree - repmat(initXfreeMean,size(initXfree,1),1))...
        *initXfreeRange*2;
    finalXfree = ...
        (finalXfree - repmat(initXfreeMean,size(finalXfree,1),1))...
        *initXfreeRange*2;
    ylabelStr = ['normalized ' isLog10Str ' parameter values'];
else
    ylabelStr = [isLog10Str ' parameter values'];
end

%% Original distribution
figure(6);
set(gcf, 'Renderer', 'zbuffer')

switch isAddOrig
    case {1,2}
        
        subplot(isAddOrig,3-isAddOrig,2);
        
        initXplot=initXfree(yellowNumInit+1:end,:);
        plot(1:freeNum,initXplot,'Color',[0,0,1],'linewidth',1)
        hold on
        initXplot=initXfree(1:yellowNumInit,:);
        plot(1:freeNum,initXplot,'Color',[1,1,0],'linewidth',1)
        
        set(gca,'FontSize',axFontSize);
        xlabel('#parameters ','FontSize',axLabelFontSize)
        title('Original','FontSize',titleFontSize)
        
        xlim([0.5 freeNum+0.5])
        if autoYlim==1
            ylimRange1 = ylim;
        end
    case 3
        initXrange = [min(initXfree);max(initXfree)];
        size(initXrange)
        h = area(initXrange');
        alpha(0.5)
        %        colormap([1 1 1;0 0 1])
        set(h(2),'FaceColor',[0 0 1])
        grid on 
        set(gca,'Layer','top')
        set(h,'LineStyle','none')
        hold on
        
end

%% Fitted distribution

switch isAddOrig
    case {0,1,2}
        
        if isAddOrig ~= 0, subplot(isAddOrig,3-isAddOrig,2), end;
        
        %{
        % Gradation
        colVec = (1./(1:finalSampNum).^0.3)';
        colVec = (colVec-colVec(end))/(1-colVec(end)); %Normalization
        colVec = [colVec colVec 1-colVec];

        for k = finalSampNum:-1:1
            plot(1:freeNum,finalXfree(k,:),'Color',colVec(k,:),'linewidth',1)
            hold on
        end
        %}
        
        finalXplot=finalXfree(yellowNumFinal+1:end,:);
        plot(1:freeNum,finalXplot,'Color',[0,0,1],'linewidth',1) % Blue
        hold on
        finalXplot=finalXfree(1:yellowNumFinal,:);
        plot(1:freeNum,finalXplot,'Color',[1,1,0],'linewidth',1) % Yellow
        
        
    case 3
        figure(7);
        set(gcf, 'Renderer', 'zbuffer')
        finalXrange = [min(finalXfree);max(finalXfree)];
        size(finalXrange)
        h = area(finalXrange');
        alpha(0.5)
%        colormap([1 1 1;1 0 0])
        set(h(2),'FaceColor',[1 0 0])
        grid on
        set(gca,'Layer','top')
        set(h,'LineStyle','none')
        hold on
end



hold off
set(gca,'FontSize',axFontSize);
xlabel('#parameters ','FontSize',axLabelFontSize)
ylabel(ylabelStr,'FontSize',axLabelFontSize)
title('Optimized','FontSize',titleFontSize)


%% Set axis properties

xlim([0.5 freeNum+0.5])
if autoYlim==1
    
    switch isAddOrig
        case {0,3}
            
            ylimRange = ylim;
        case {1,2}
            
            ylimRange2 = ylim;
            ylimRange = ...
                [min(ylimRange1(1),ylimRange2(1)) max(ylimRange1(2),ylimRange2(2))];
    end
end

switch isAddOrig
    case 0
        ylim(ylimRange); grid;
        if isNormalize, addytick(1);addytick(-1); end
        set(gca,'xtick',1:5:freeNum);
    case {1,2}
        
        subplot(isAddOrig,3-isAddOrig,2); ylim(ylimRange); grid;
        if isNormalize, addytick(1);addytick(-1); end
        set(gca,'xtick',1:5:freeNum);
        
        subplot(isAddOrig,3-isAddOrig,1); ylim(ylimRange); grid;
        if isNormalize, addytick(1);addytick(-1); end
        set(gca,'xtick',1:5:freeNum);
    case 3
        
        
        set(h,'BaseValue',ylimRange(1))
end

set(gcf,'Position',[20,20,1280,600]);

end

function addytick( tk, tklbl )
%ADDXTICK --- Add new tick to x-axis
%   Ex.    addxtick(3.14)
%   Ex2.  addxtick(3.14, 'Pi')
%
% http://ichiro-maruta.blogspot.jp/2009/01/matlab.html

if nargin==1
    set(gca,'YTick',unique(sort([get(gca,'YTick'), tk ] )));
else
    temp = cellstr(get(gca,'YTickLabel'));
    % temp = {temp{:},tklbl};
    % If A is a cell array with a single row, replace { A{:} X } with [A {X}]
    temp = [temp {tklbl}];
    [temp2,idx] = sort([get(gca,'YTick'),tk]);
    [temp2,idx2]=unique(temp2);
    idx=idx(idx2);
    set(gca,'YTick',temp2);
    set(gca,'YTickLabel',temp(idx));
end

end
