function [out] = sym2str(sy)
%updated:  02-03-2009
%author: Marty Lawson
%
%converts symbolic variables to a matlab equation string insuring that
%only array opps are used.
%Symbolic arrays are converted to linear Cell arrays of strings.
%This function is especially usefull when combined with the eval() command.
%Also, converts maple atan function to matlab atan2 and converts
%maple "array([[a,b],[c,d]])" notation to matlab "[a,b;c,d]" notation.
%
%Note: eval() of a matrix of functions only works if all the input
%variables have single values.  i.e. vectors and arrays won't work.
%
%Note2: eval() does not work on Cell arrays directly.  Use "Cell_array{index}"
%inside of the eval() to keep eval() happy
%
%	EXAMPLE:
%
% X_t = dsolve('5*D2x+6*Dx+3*x = 10*sin(10*t)','x(0)=0','Dx(0)=3'); %solution is a symbolic function, X(t)
% X_t_str = sym2str(X_t);							                %convert from symbolic type to char type using array operations
% t = 0:.01:20;									                    %make "t" an array containing the time range of interest for X(t)
% X_t_vec = eval(X_t_str);							                %see "help eval" for details.
% plot(t,X_t_vec)									                %plot the results
% grid on										                    %make the plot look nice
% xlabel('time [radians]')
% ylabel('amplitude [-]')
%
sy = sym(sy); %insure input is symbolic
siz = numel(sy);   %find the number of elements in "sy"
for i = 1:siz   %dump it into a cell array with the same number of elements
  in{i} = char(sy(i)); %convert to char
  in{i} = strrep(in{i},'^','.^');%insure that all martix opps are array opps
  in{i} = strrep(in{i},'*','.*');
  in{i} = strrep(in{i},'/','./');
  in{i} = strrep(in{i},'atan','atan2'); %fix the atan function
  in{i} = strrep(in{i},'array([[','['); %clean up any maple array notation
  in{i} = strrep(in{i},'],[',';');
  in{i} = strrep(in{i},']])',']');
end
if siz == 1
  in = char(in);      %revert back to a 'char' array for single answers
end
%% modification by Yoshida
if siz ==0
  in = 'empty string';
end
%%
  
out = in;

%{
    Copyright (c) 2008, Martin Lawson
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the distribution
      
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

%}